=================
Phase Curve Tools
=================


.. image:: https://img.shields.io/pypi/v/phase_curve_tools.svg
        :target: https://pypi.python.org/pypi/phase_curve_tools

.. image:: https://readthedocs.org/projects/phase-curve-tools/badge/?version=latest
        :target: https://phase-curve-tools.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status

.. image:: https://github.com/drk98/phase_curve_tools/actions/workflows/python-app.yml/badge.svg
        :target: https://github.com/drk98/phase_curve_tools/actions/workflows/python-app.yml
        :alt: Test Results


A Python package for asteroid phase curves


* Free software: MIT license
* Documentation: https://phase-curve-tools.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
